import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**主页面列表 表头*/
export const columns: BasicColumn[] = [
  {
    title: '标准中文名称',
    dataIndex: 'standardChineseName',
    width: 150,
  },
  {
    title: '标准编号',
    dataIndex: 'standardCode',
    width: 150,
  },
  {
    title: '引用标准',
    dataIndex: 'referenceStandard',
    width: 150,
    slots: { customRender: 'referenceStandard' },
  },
  {
    title: '业务定义',
    dataIndex: 'businessDefinition',
    width: 150,
  },
  {
    title: '发布状态',
    dataIndex: 'publishStatus',
    width: 150,
  },
  {
    title: '权属工作组',
    dataIndex: 'holderGroup',
    width: 150,
  },
];
/**主页面搜索 表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'standardCode',
    label: '标准编号',
    component: 'Input',
    componentProps: {
      placeholder: '请输入标准编号',
    },
    colProps: { span: 6 },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
    colProps: { span: 6 },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    componentProps: {
      placeholder: '请输入业务定义',
    },
    colProps: { span: 6 },
  },
];
/**导入关联关系 表单*/
export const importRelativeFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '关联关系重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
      ],
    },
  },
];
/**导入数据标准 表单*/
export const importDataStandardsFormSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '标准重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
        {
          label: '自动重命名',
          value: '3',
        },
      ],
    },
  },
];
/**移动 表单*/
export const moveFormSchema: any[] = [
  {
    field: 'treeId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**重命名 表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**新建标准分类 表单*/
export const createBasicTypeFormSchema: FormSchema[] = [
  {
    field: 'standardsTree',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'standardsTypeName',
    label: '标准分类名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准分类名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准分类名称',
    },
  },
  {
    field: 'standardsTypeDescription',
    label: '标准分类描述',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准分类描述',
      },
    ],
    componentProps: {
      placeholder: '请输入标准分类描述',
    },
  },
  {
    field: 'ModelTree',
    label: '关联元模型',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'permissionMode',
    label: '权限模式',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '本级定义', value: '1' },
        { label: '资源自定义', value: '0' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'username',
    label: '权属工作组',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options:[
        {
          label: '默认工作组',
          value: '1',
        },
        {
          label: '个人工作组',
          value: '2',
        },
        {
          label: '共享工作组',
          value: '3',
        },
      ]
    },
    rules: [
      {
        required: true,
        message: '请输入权属工作组',
      },
    ],
  },
];
/**新建基础标准 表单*/
export const createBasicStandardsFormSchema: FormSchema[] = [
  {
    field: 'standardsTree',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'standardsName',
    label: '标准名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准名称',
    },
  },
  {
    field: 'standardsTypeName',
    label: '标准类型',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '基础标准',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入标准类型',
      },
    ],
  },
  {
    field: 'permissionMode',
    label: '目录权属模式',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '本级定义',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入目录权属模式',
      },
    ],
  },
  {
    field: 'username',
    label: '权属工作组',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    rules: [
      {
        required: true,
        message: '请输入权属工作组',
      },
    ],
  },
];

/**基础标准详情 表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: '',
    label: '业务属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准英文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准英文名称',
    },
  },
  {
    field: 'standardAlias',
    label: '标准别名',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准别名',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准别名',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务定义',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入定义依据',
    },
  },
  {
    field: 'businessRule',
    label: '业务规则',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务规则',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务规则',
    },
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择数据类型',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'文本类',
          value:'1'
        },
        {
          label:'数值类',
          value:'2'
        },
        {
          label:'代码类',
          value:'3'
        },
        {
          label:'标志类',
          value:'4'
        },
        {
          label:'日期时间类',
          value:'5'
        },
        {
          label:'编号类',
          value:'6'
        },
      ],
      placeholder: '请选择数据类型',
    },
  },
  {
    field: 'valueRange',
    label: '取值范围',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入取值范围',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入取值范围',
    },
  },
  {
    field: 'codeNumber',
    label: '代码编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入代码编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入代码编号',
    },
  },
  {
    field: 'adaptability',
    label: '适应性',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入适应性',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'当前适用',
          value:'1'
        },
        {
          label:'未来适用',
          value:'2'
        },
      ],
      placeholder: '请输入适应性',
    },
  }
];
/**基础标准详情 表单2*/
export const detailSchema2: FormSchema[] = [
  {
    field: '',
    label: '技术属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'dataDisplay',
    label: '数据显示',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据显示',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据显示',
    },
  },
  {
    field: 'tecDataType',
    label: '数据类型',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据类型',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据类型',
    },
  },
  {
    field: 'dataPrecision',
    label: '数据精度',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据精度',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据精度',
    },
  },
  {
    field: 'dataLength',
    label: '数据长度',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据长度',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据长度',
    },
  },
  {
    field: 'measurementUnit',
    label: '计量单位',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入计量单位',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入计量单位',
    },
  }
];
/**基础标准详情 表单3*/
export const detailSchema3: FormSchema[] = [
  {
    field: '',
    label: '管理属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'creator',
    label: '创建人员',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入创建人员',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建人员',
    },
  },
  {
    field: 'updater',
    label: '更新人员',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入更新人员',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新人员',
    },
  },
  {
    field: 'createDate',
    label: '创建日期',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入创建日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建日期',
    },
  },
  {
    field: 'updateDate',
    label: '更新日期',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入更新日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新日期',
    },
  },
  {
    field: 'secondaryAuthorityDepartment',
    label: '权威二级部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入权威二级部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威二级部门',
    },
  },
  {
    field: 'tertiaryAuthorityDepartment',
    label: '权威三级部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入权威三级部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威三级部门',
    },
  },
  {
    field: 'coreSystem',
    label: '核心系统',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入核心系统',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入核心系统',
    },
  },
  {
    field: 'dataStandardStatus',
    label: '数据标准状态',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据标准状态',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'有效',
          value:'1'
        },
        {
          label:'失效',
          value:'2'
        },
        {
          label:'未生效',
          value:'3'
        }
      ],
      placeholder: '请输入数据标准状态',
    },
  },
  {
    field: 'expirationDate',
    label: '失效时间',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入失效时间',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'expirationReason',
    label: '失效原因',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入失效原因',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入失效原因',
    },
  },
  {
    field: 'collaborativeDepartment',
    label: '协作部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入协作部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入协作部门',
    },
  }
];


/**编辑基础标准 表单1*/
export const editStandardsDetailFormSchema1: FormSchema[] = [
  {
    field: 'businessAttribute',
    label: '业务属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准英文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准英文名称',
    },
  },
  {
    field: 'standardAlias',
    label: '标准别名',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准别名',
      },
    ],
    componentProps: {
      placeholder: '请输入标准别名',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      placeholder: '请输入业务定义',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      placeholder: '请输入定义依据',
    },
  },
  {
    field: 'businessRule',
    label: '业务规则',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务规则',
      },
    ],
    componentProps: {
      placeholder: '请输入业务规则',
    },
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择数据类型',
      },
    ],
    componentProps: {
      options:[
        {
          label:'文本类',
          value:'1'
        },
        {
          label:'数值类',
          value:'2'
        },
        {
          label:'代码类',
          value:'3'
        },
        {
          label:'标志类',
          value:'4'
        },
        {
          label:'日期时间类',
          value:'5'
        },
        {
          label:'编号类',
          value:'6'
        },
      ],
      placeholder: '请选择数据类型',
    },
  },
  {
    field: 'valueRange',
    label: '取值范围',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入取值范围',
      },
    ],
    componentProps: {
      placeholder: '请输入取值范围',
    },
  },
  {
    field: 'codeNumber',
    label: '代码编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入代码编号',
      },
    ],
    componentProps: {
      placeholder: '请输入代码编号',
    },
  },
  {
    field: 'adaptability',
    label: '适应性',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入适应性',
      },
    ],
    componentProps: {
      options:[
        {
          label:'当前适用',
          value:'1'
        },
        {
          label:'未来适用',
          value:'2'
        },
      ],
      placeholder: '请输入适应性',
    },
  }
];
/**编辑基础标准 表单2*/
export const editStandardsDetailFormSchema2: FormSchema[] = [
  {
    field: 'technicalAttribute',
    label: '技术属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'dataDisplay',
    label: '数据显示',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据显示',
      },
    ],
    componentProps: {
      placeholder: '请输入数据显示',
    },
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据类型',
      },
    ],
    componentProps: {
      placeholder: '请输入数据类型',
    },
  },
  {
    field: 'dataPrecision',
    label: '数据精度',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据精度',
      },
    ],
    componentProps: {
      placeholder: '请输入数据精度',
    },
  },
  {
    field: 'dataLength',
    label: '数据长度',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据长度',
      },
    ],
    componentProps: {
      placeholder: '请输入数据长度',
    },
  },
  {
    field: 'measurementUnit',
    label: '计量单位',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入计量单位',
      },
    ],
    componentProps: {
      placeholder: '请输入计量单位',
    },
  }
];
/**编辑基础标准 表单3*/
export const editStandardsDetailFormSchema3: FormSchema[] = [
  {
    field: 'managementAttribute',
    label: '管理属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'creator',
    label: '创建人员',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入创建人员',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入创建人员',
    },
  },
  {
    field: 'updater',
    label: '更新人员',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入更新人员',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入更新人员',
    },
  },
  {
    field: 'creationDate',
    label: '创建日期',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入创建日期',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入创建日期',
    },
  },
  {
    field: 'updateDate',
    label: '更新日期',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入更新日期',
      },
    ],
    componentProps: {
      disabled: true,
      placeholder: '请输入更新日期',
    },
  },
  {
    field: 'secondaryAuthorityDepartment',
    label: '权威二级部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入权威二级部门',
      },
    ],
    componentProps: {
      placeholder: '请输入权威二级部门',
    },
  },
  {
    field: 'tertiaryAuthorityDepartment',
    label: '权威三级部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入权威三级部门',
      },
    ],
    componentProps: {
      placeholder: '请输入权威三级部门',
    },
  },
  {
    field: 'coreSystem',
    label: '核心系统',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入核心系统',
      },
    ],
    componentProps: {
      placeholder: '请输入核心系统',
    },
  },
  {
    field: 'dataStandardStatus',
    label: '数据标准状态',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入数据标准状态',
      },
    ],
    componentProps: {
      options:[
        {
          label:'有效',
          value:'1'
        },
        {
          label:'失效',
          value:'2'
        },
        {
          label:'未生效',
          value:'3'
        }
      ],
      placeholder: '请输入数据标准状态',
    },
  },
  {
    field: 'expirationDate1',
    label: '失效时间',
    component: 'DatePicker',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入失效时间',
      },
    ],
    componentProps: {
      style: {
        width: '100%',
      },
      getPopupContainer: () => {
        return document.querySelector('.ant-form')!;
      },
    },
  },
  {
    field: 'expirationReason',
    label: '失效原因',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入失效原因',
      },
    ],
    componentProps: {
      placeholder: '请输入失效原因',
    },
  },
  {
    field: 'collaborativeDepartment',
    label: '协作部门',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入协作部门',
      },
    ],
    componentProps: {
      placeholder: '请输入协作部门',
    },
  }
];

/**版本对比 表单*/
export const contrastSchema: FormSchema[] = [
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准英文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准英文名称',
    },
  },
  {
    field: 'standardAlias',
    label: '标准别名',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入标准别名',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准别名',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务定义',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入定义依据',
    },
  },
  {
    field: 'businessRule',
    label: '业务规则',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入业务规则',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务规则',
    },
    slot: 'businessRule'
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请选择数据类型',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'文本类',
          value:'1'
        },
        {
          label:'数值类',
          value:'2'
        },
        {
          label:'代码类',
          value:'3'
        },
        {
          label:'标志类',
          value:'4'
        },
        {
          label:'日期时间类',
          value:'5'
        },
        {
          label:'编号类',
          value:'6'
        },
      ],
      placeholder: '请选择数据类型',
    },
  },
  {
    field: 'valueRange',
    label: '取值范围',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入取值范围',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入取值范围',
    },
  },
  {
    field: 'codeNumber',
    label: '代码编号',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入代码编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入代码编号',
    },
  },
  {
    field: 'adaptability',
    label: '适应性',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入适应性',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'当前适用',
          value:'1'
        },
        {
          label:'未来适用',
          value:'2'
        },
      ],
      placeholder: '请输入适应性',
    },
  },
  {
    field: 'dataDisplay',
    label: '数据显示',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入数据显示',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据显示',
    },
  },
  {
    field: 'tecDataType',
    label: '数据类型',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入数据类型',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据类型',
    },
  },
  {
    field: 'dataPrecision',
    label: '数据精度',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入数据精度',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据精度',
    },
  },
  {
    field: 'dataLength',
    label: '数据长度',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入数据长度',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据长度',
    },
  },
  {
    field: 'measurementUnit',
    label: '计量单位',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入计量单位',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入计量单位',
    },
  },
  {
    field: 'creator',
    label: '创建人员',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入创建人员',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建人员',
    },
  },
  {
    field: 'updater',
    label: '更新人员',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入更新人员',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新人员',
    },
  },
  {
    field: 'createDate',
    label: '创建日期',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入创建日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建日期',
    },
  },
  {
    field: 'updateDate',
    label: '更新日期',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入更新日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新日期',
    },
  },
  {
    field: 'secondaryAuthorityDepartment',
    label: '权威二级部门',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入权威二级部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威二级部门',
    },
  },
  {
    field: 'tertiaryAuthorityDepartment',
    label: '权威三级部门',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入权威三级部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威三级部门',
    },
  },
  {
    field: 'coreSystem',
    label: '核心系统',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入核心系统',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入核心系统',
    },
  },
  {
    field: 'dataStandardStatus',
    label: '数据标准状态',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入数据标准状态',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'有效',
          value:'1'
        },
        {
          label:'失效',
          value:'2'
        },
        {
          label:'未生效',
          value:'3'
        }
      ],
      placeholder: '请输入数据标准状态',
    },
  },
  {
    field: 'expirationDate',
    label: '失效时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入失效时间',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'expirationReason',
    label: '失效原因',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入失效原因',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入失效原因',
    },
  },
  {
    field: 'collaborativeDepartment',
    label: '协作部门',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入协作部门',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入协作部门',
    },
  }
];

/**关联关系 表头1*/
export const relatedRelationshipColumns1: BasicColumn[] = [
  {
    title: '质量模版名称',
    dataIndex: 'qualityTemplateName',
    width: 150,
    slots: { customRender: 'qualityTemplateName' },
  },
  {
    title: '数据源',
    dataIndex: 'dataSource',
    width: 150,
    slots: { customRender: 'dataSource' },
  },
  {
    title: '质量模版编号',
    dataIndex: 'qualityTemplateNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系 表头2*/
export const relatedRelationshipColumns2: BasicColumn[] = [
  {
    title: '文档名称',
    dataIndex: 'documentName',
    width: 150,
    slots: { customRender: 'documentName' },
  },
  {
    title: '文档编号',
    dataIndex: 'documentNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系 表头3*/
export const relatedRelationshipColumns3: BasicColumn[] = [
  {
    title: '标准名称',
    dataIndex: 'standardName',
    width: 150,
    slots: { customRender: 'standardName' },
  },
  {
    title: '标准编号',
    dataIndex: 'standardNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系 表头4*/
export const relatedRelationshipColumns4: BasicColumn[] = [
  {
    title: '公共代码名称',
    dataIndex: 'commonCodeName',
    width: 150,
    slots: { customRender: 'commonCodeName' },
  },
  {
    title: '标准编号',
    dataIndex: 'standardNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系 表头5*/
export const relatedRelationshipColumns5: BasicColumn[] = [
  {
    title: '标准名称',
    dataIndex: 'standardName',
    width: 150,
    slots: { customRender: 'standardName' },
  },
  {
    title: '标准编号',
    dataIndex: 'standardNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];
/**关联关系 表头6*/
export const relatedRelationshipColumns6: BasicColumn[] = [
  {
    title: '数据源',
    dataIndex: 'dataSource',
    width: 150,
  },
  {
    title: '目录',
    dataIndex: 'directory',
    width: 150,
  },
  {
    title: '数据库',
    dataIndex: 'database',
    width: 150,
  },
  {
    title: '数据表',
    dataIndex: 'dataTable',
    width: 150,
    slots: { customRender: 'dataTable' },
  },
  {
    title: '字段',
    dataIndex: 'field',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];

/**关联关系-关联质量 表单*/
export const relatedQualitySchema: any[] = [
  {
    field: 'QualityId',
    label: '关联质量模版',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'QualityName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-关联质量 列表*/
export const relatedQualityColumns: BasicColumn[] = [
  {
    title: '参数',
    dataIndex: 'parameter',
    width: 150,
  },
  {
    title: '模版类型',
    dataIndex: 'templateType',
    width: 150,
  },
  {
    title: '模版描述',
    dataIndex: 'templateDescription',
    width: 150,
  },
  {
    title: '值',
    dataIndex: 'value',
    width: 150,
    editable: true,
    edit:true
  },
];
/**关联关系-关联基础标准 表单*/
export const relatedBasicStandardsSchema: any[] = [
  {
    field: 'basicStandardsTree',
    label: '关联基础标准',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择关联关系',
      },
    ],
    componentProps: {
      options:[
        {
          label: '引用',
          value: '引用'
        },
        {
          label: '同义词',
          value: '同义词'
        },
        {
          label: '依赖',
          value: '依赖'
        },
        {
          label: '从属',
          value: '从属'
        }
      ],
      placeholder: '请选择关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-关联指标标准 表单*/
export const relatedIndicatorStandardsSchema: any[] = [
  {
    field: 'indicatorStandardsTree',
    label: '关联指标标准',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'indicatorStandardsName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择关联关系',
      },
    ],
    componentProps: {
      options:[
        {
          label: '引用',
          value: '引用'
        },
        {
          label: '同义词',
          value: '同义词'
        },
        {
          label: '依赖',
          value: '依赖'
        },
        {
          label: '从属',
          value: '从属'
        }
      ],
      placeholder: '请选择关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-关联公共代码 表单*/
export const relatedPublicCodeSchema: any[] = [
  {
    field: 'publicCodeTree',
    label: '关联公共代码',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'publicCodeName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择关联关系',
      },
    ],
    componentProps: {
      options:[
        {
          label: '引用',
          value: '引用'
        },
        {
          label: '同义词',
          value: '同义词'
        },
        {
          label: '依赖',
          value: '依赖'
        },
        {
          label: '从属',
          value: '从属'
        }
      ],
      placeholder: '请选择关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-关联文档 表单*/
export const relatedDocumentSchema: any[] = [
  {
    field: 'documentTree',
    label: '关联文档模版',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'documentName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择关联关系',
      },
    ],
    componentProps: {
      options:[
        {
          label: '引用',
          value: '引用'
        },
        {
          label: '同义词',
          value: '同义词'
        },
        {
          label: '依赖',
          value: '依赖'
        },
        {
          label: '从属',
          value: '从属'
        }
      ],
      placeholder: '请选择关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-关联元数据 表单*/
export const relatedMeteDataSchema: any[] = [
  {
    field: 'meteDataTree',
    label: '关联元数据',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
/**关联关系-智能推荐元数据 表单*/
export const recommendedMetadataSchema: FormSchema[] = [
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    defaultValue: '/基础标准/DMP_admin-个人工作区/当前就读学校',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准路径',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'dataSource',
    label: '数据源',
    component: 'Input',
    defaultValue: 'argodb_test',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入数据源',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    defaultValue: '当前就读学校',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准中文名称',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    defaultValue: 'current_school',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准英文名称',
    },
    colProps: { lg: 12, md: 12 },
  },
];
/**关联关系-智能推荐元数据 列表*/
export const recommendedMetadataColumns: BasicColumn[] = [
  {
    title: '字段名称',
    dataIndex: 'fieldName',
    width: 150,
  },
  {
    title: '字段注释',
    dataIndex: 'fieldComment',
    width: 150,
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    width: 150,
  },
  {
    title: '推荐度',
    dataIndex: 'recommendationLevel',
    width: 150,
  },
  {
    title: '映射描述',
    dataIndex: 'mappingDescription',
    width: 150,
    editable: true,
    edit: true
  },
];
/**关联关系-智能推荐元数据-提示 表单*/
export const recommendedMetadataTipsSchema: FormSchema[] = [
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    defaultValue: '/基础标准/DMP_admin-个人工作区/当前就读学校',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准路径',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    defaultValue: '当前就读学校',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准中文名称',
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    defaultValue: 'current_school',
    componentProps: {
      style: {
        border:'none',
      },
      readOnly: true,
      disabled: true,
      placeholder: '请输入标准英文名称',
    },
    colProps: { lg: 12, md: 12 },
  },
];


/**发布 1*/
export const formSchemaPublish: any = [
  {
    field: 'title',
    label: '申请标题',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    colProps: { span: 24 },
    componentProps: {
      placeholder: '',
    },
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    colProps: { span: 24 },
    componentProps: {
      placeholder: '',
    },
  },
  {
    field: 'user',
    label: '申请人',
    component: 'Input',
    defaultValue:'admin',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'organization',
    label: '申请人组织',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
/**发布 2*/
export const formSchemaPublishTwo: any = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '数据标准路径',
    component: 'Input',
    defaultValue:'域/共享工作区/短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const formSchemaImport: any = [
  {
    field: 'path',
    label: '选择文件地址',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
]
export const batchColumns: BasicColumn[] = [
  {
    title: '日期类',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '共享工作区/日期类',
    dataIndex: 'type',
    width: 120,
  },
]
export const applySchemas: FormSchema[] = [
  {
    field: '',
    label: '申请信息',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'申请发布<日期类>等2个域',
    componentProps: {
    }
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
    defaultValue:'',
    componentProps: {
    }
  },
  {
    field: 'user',
    label: '申请人',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'org',
    label: '所属机构',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'time',
    label: '申请时间',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const applySchemas1: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '搜索资源名称',
    }
  }
]
export const applySchemas2: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'日期类',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    defaultValue:'共享工作区/日期类',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const applySchemas3: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    defaultValue:'共享工作区/短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]

