import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {relatedQualityColumns} from "@/views/dataStandards/basicStandards/basicStandards.data"; // 引入开关组件
type CheckedType = boolean | string | number;

/**版本管理列表 表头*/
export const versionColumns: BasicColumn[] = [
  {
    title: '版本ID',
    dataIndex: 'versionId',
    width: 150,
  },
  {
    title: '版本名称',
    dataIndex: 'versionName',
    width: 150,
  },
  {
    title: '提交人',
    dataIndex: 'submitBy',
    width: 150,
  },
  {
    title: '提交时间',
    dataIndex: 'submitDate',
    width: 150,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 150,
  },
];

/**版本管理弹出框 搜索表头*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '请输入版本名称',
    },
    colProps: { span: 7 },
  },
];

/**主页面树/列表 数据*/
export const TreeData: any[] = [
  {
    "businessId": 100,
    "standardChineseName": "基础标准",
    "anotherName": "基础标准",
    "parentId": 0,
    "businessDefinition": "基础标准",
    "location": "/基础标准",
    "publishStatus": "已发布",
    "holderGroup": "默认工作组",
    "standardCode": "BAS000001",
    "referenceStandard":[
      { icon: '😂', text: '数据源1' },
      { icon: '🔍', text: '数据源2' },
    ],
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "通用",
    "standardNumber": "BAS-001",
    "standardEnglishName": "Basic Standard",
    "standardAlias": "Basic Standard",
    "standardSource": "1",
    "definitionBasis": "相关法律法规",
    "businessRule": "所有基础标准必须经过审核才能发布。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-100",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "张三",
    "updater": "李四",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "研发组",
    "coreSystem": "核心系统A",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "财务部, 市场部"
  },
  {
    "businessId": 101,
    "standardChineseName": "共享工作区",
    "anotherName": "共享工作区",
    "parentId": 100,
    "businessDefinition": "共享工作区",
    "publishStatus": "已发布",
    "ancestors": "0,100",
    "standardCode": "BAS000002",
    "location": "/基础标准/共享工作区",
    "holderGroup": "共享工作区",
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:folder-open-outlined",
    "businessAttribute": "协作",
    "standardNumber": "BAS-002",
    "standardEnglishName": "Shared Workspace",
    "standardAlias": "Shared Workspace",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "共享工作区内的文件必须定期备份。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-101",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "张三",
    "updater": "李四",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "研发组",
    "coreSystem": "核心系统A",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "财务部, 市场部"
  },
  {
    "businessId": 102,
    "standardChineseName": "个人工作区",
    "anotherName": "个人工作区",
    "parentId": 100,
    "publishStatus": "未发布",
    "businessDefinition": "个人工作区",
    "standardCode": "BAS000003",
    "ancestors": "0,100",
    "location": "/基础标准/个人工作区",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-24 10:04:04",
    "updateDate": "2024-10-24 10:04:04",
    "icon": "ant-design:folder-open-outlined",
    "businessAttribute": "个人",
    "standardNumber": "BAS-003",
    "standardEnglishName": "Personal Workspace",
    "standardAlias": "Personal Workspace",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "个人工作区内的文件必须定期清理。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-102",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "1",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的出资方式必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 202,
    "standardChineseName": "对外投资控股标志",
    "anotherName": "对外投资控股标志",
    "parentId": 102,
    "publishStatus": "未发布",
    "businessDefinition": "对外投资控股标志",
    "standardCode": "BAS000005",
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资控股标志",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-005",
    "standardEnglishName": "Investment Holding Mark",
    "standardAlias": "Investment Holding Mark",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的控股标志必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-202",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 203,
    "standardChineseName": "对外投资企业证明",
    "anotherName": "对外投资企业证明",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资企业证明",
    "standardCode": "BAS000006",
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资企业证明",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-006",
    "standardEnglishName": "Investment Company Proof",
    "standardAlias": "Investment Company Proof",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的企业证明必须合法有效。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-203",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
  {
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "businessId": 204,
    "standardChineseName": "zy_basic_standard",
    "anotherName": "zy_basic_standard",
    "parentId": 101,
    "publishStatus": "已发布",
    "businessDefinition": "zy_basic_standard",
    "standardCode": "BAS000007",
    "ancestors": "0,100,101",
    "location": "/基础标准/共享工作区/zy_basic_standard",
    "holderGroup": "共享工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "通用",
    "standardNumber": "BAS-007",
    "standardEnglishName": "ZY Basic Standard",
    "standardAlias": "ZY Basic Standard",
    "standardSource": "1",
    "definitionBasis": "用户需求分析",
    "businessRule": "所有基本标准必须经过审核才能发布。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-204",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  }
];

export const fileData: any[] = [
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 300,
      "username" : "file1",
      "nickName" : "测试文件流1",
      "name" : "测试文件流1",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 301,
      "username" : "file2",
      "nickName" : "测试文件流2",
      "name" : "测试文件流2",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 302,
      "username" : "file3",
      "nickName" : "测试文件流3",
      "name" : "测试文件流3",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },
    {
      "delFlag" : "0",
      "flag" : "1",
      "businessId" : 303,
      "username" : "file4",
      "nickName" : "测试文件流4",
      "name" : "测试文件流4",
      "fileSize": 1024,
      "holder":"admin",
      "createDate": "2024-10-24 10:04:04",
      "updateDate": "2024-10-24 10:04:04",
      "institutionId" : 105,
      "institutionName" : "财务部门",
      "menuList" : [ ]
    },

];

/**版本管理列表 数据*/
export const versionData: any[] = [
  {
    "versionId":"1",
    "versionName":"V1",
    "submitBy":"admin",
    "submitDate":"2021/11/15 18:55:06",
    "remarks":"STANDARD_BASIC添加发布的第一个版"
  },
  {
    "versionId":"2",
    "versionName":"V2",
    "submitBy":"admin",
    "submitDate":"2021/11/11 18:55:06",
    "remarks":"STANDARD_BASIC添加发布的第二个版"
  },
  {
    "versionId":"3",
    "versionName":"V3",
    "submitBy":"admin",
    "submitDate":"2021/11/11 18:55:06",
    "remarks":"标准导入"
  },
];


/**首页 新增表单树 数据*/
export const treeDataListTwo = [
  {
    label: '默认工作组',
    businessId: 1,
    children: [
      { label: '默认工作组01', businessId: 2 },
      { label: '默认工作组02', businessId: 3 },
      { label: '默认工作组03', businessId: 4 },
      { label: '默认工作组04', businessId: 5 },
    ],
  },
]
/**首页 新增基础分类 基础元模型树*/
export const dataBasicTreeData: any[] = [
  {
    delFlag: '0',
    flag: '1',
    businessId: 100,
    modelName: '数据标准模型',
    parentId: 0,
    code: '001',
    ancestors: '0',
    orderNum: 0,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    selectType: null,
    type: 'MySQL',
    icon: 'ion:settings-outline',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 101,
    modelName: '数据标准模型文件夹1',
    parentId: 100,
    code: '002',
    ancestors: '0,100',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 102,
    modelName: '数据标准模型文件夹2',
    parentId: 100,
    code: '002',
    ancestors: '0,100',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 103,
    modelName: '数据标准模型文件夹3',
    parentId: 100,
    code: '002',
    ancestors: '0,100',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 201,
    modelName: 'argodb元模型',
    parentId: 101,
    'code:': '002',
    ancestors: '0,100，101',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 202,
    modelName: 'inceptor元模型',
    parentId: 101,
    'code:': '002',
    ancestors: '0,100，101',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 203,
    modelName: 'acc元模型',
    parentId: 102,
    'code:': '002',
    ancestors: '0,100，102',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 204,
    modelName: 'ctor元模型',
    parentId: 102,
    'code:': '002',
    ancestors: '0,100，102',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 205,
    modelName: 'octp元模型',
    parentId: 103,
    'code:': '002',
    ancestors: '0,100，103',
    orderNum: 1,
    selectType: null,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    icon: 'ant-design:codepen-outlined',
  },
];

/**编辑页 选择字典树 数据*/
export const chooseDictoryTreeData = [
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 100,
    "basicStandardName" : "所有命名字典",
    "anotherName":"所有命名字典",
    "parentId" : 0,
    "ancestors" : "0",
    "orderNum" : 0,
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 101,
    "basicStandardName" : "共享工作区",
    "anotherName":"共享工作区",
    "parentId" : 100,
    "ancestors" : "0,100",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 102,
    "basicStandardName" : "关联域",
    "anotherName":"关联域",
    "parentId" : 101,
    "ancestors" : "0,100,101",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 103,
    "basicStandardName" : "日期",
    "anotherName":"日期",
    "parentId" : 102,
    "ancestors" : "0,100,101,102",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
  {
    "delFlag" : "0",
    "flag" : "1",
    "businessId" : 104,
    "basicStandardName" : "创建日期",
    "anotherName":"创建日期",
    "parentId" : 102,
    "ancestors" : "0,100,101,102",
    "children" : [ ],
    icon: 'ion:settings-outline',
  },
]

/**对比左侧数据*/
export const leftContrastData: any[] = [
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "记录对外投资。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
]
/**对比右侧数据*/
export const rightContrastData = [
  {
    "businessId": 201,
    "standardChineseName": "对外投资出资方式",
    "anotherName": "对外投资出资方式",
    "parentId": 102,
    "publishStatus": "已发布",
    "businessDefinition": "对外投资出资方式",
    "standardCode": "BAS000004",
    "referenceStandard":[
      { icon: '🌐🔍', text: '数据源1' },
    ],
    "ancestors": "0,100,102",
    "location": "/基础标准/个人工作区/对外投资出资方式",
    "holderGroup": "个人工作区",
    "createDate": "2024-10-22 8:04:04",
    "updateDate": "2024-10-22 8:04:04",
    "icon": "ant-design:partition-outlined",
    "businessAttribute": "财务",
    "standardNumber": "BAS-004",
    "standardEnglishName": "Investment Contribution Method",
    "standardAlias": "Investment Contribution Method",
    "standardSource": "国家标准化管理委员会",
    "definitionBasis": "相关法律法规",
    "businessRule": "对外投资的出资方式必须明确记录。",
    "dataType": "1",
    "tecDataType": "varchar",
    "valueRange": "非空字符串",
    "codeNumber": "CODE-201",
    "adaptability": "1",
    "technicalAttribute": "通用技术属性",
    "dataDisplay": "文本显示",
    "dataPrecision": "无",
    "dataLength": "255",
    "measurementUnit": "无",
    "managementAttribute": "通用管理属性",
    "creator": "王五",
    "updater": "赵六",
    "secondaryAuthorityDepartment": "技术部",
    "tertiaryAuthorityDepartment": "运维组",
    "coreSystem": "核心系统B",
    "dataStandardStatus": "有效",
    "expirationDate": "2025-10-24",
    "expirationReason": "无",
    "collaborativeDepartment": "人力资源部, 技术部"
  },
]


/**关联关系 表格1 数据*/
export const relatedRelationshipsData1 = [
  {
    businessId: '1',
    qualityTemplateName: '非空检查(不为NULL)',
    dataSource: [
      { icon: '🌐🔍', text: '数据源1' },
    ],
    qualityTemplateNumber: 'BIDQ000000001',
    path: '/质量模版/DMP_admin-个人工作区/...',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '2',
    qualityTemplateName: '长度检查=2',
    dataSource: [
      { icon: '🌐🔍', text: '数据源1' },
    ],
    qualityTemplateNumber: 'DQ000011',
    path: '/质量模版/DMP_admin-个人工作区/...',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-02 11:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '3',
    qualityTemplateName: '值域检查',
    dataSource: [
      { icon: '🌐🔍', text: '数据源1' },
    ],
    qualityTemplateNumber: 'DQ000013',
    path: '/质量模版/DMP_admin-个人工作区/...',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-03 12:00:00',
    operatorUser: 'DMP_admin',
  },
]
/**关联关系 表格2 数据*/
export const relatedRelationshipsData2 = [
  {
    businessId: '1',
    documentName: '非空检查(不为NULL)',
    documentNumber: 'BIDQ000000001',
    path: '/引用文档/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '2',
    documentName: '长度检查=2',
    documentNumber: 'DQ000011',
    path: '/引用文档/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-02 11:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '3',
    documentName: '值域检查',
    documentNumber: 'DQ000013',
    path: '/引用文档/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-03 12:00:00',
    operatorUser: 'DMP_admin',
  },
]
/**关联关系 表格3 数据*/
export const relatedRelationshipsData3 = [
  {
    businessId: '1',
    standardName: '当前就读学校',
    standardNumber: 'BIDQ000000001',
    path: '/基础标准/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '无',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
]
/**关联关系 表格4 数据*/
export const relatedRelationshipsData4 = [
  {
    businessId: '1',
    commonCodeName: '是否为全日制',
    standardNumber: 'COM000002',
    path: '/公共代码/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '"是否全日"作为毕业...',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
]
/**关联关系 表格5 数据*/
export const relatedRelationshipsData5 = [
  {
    businessId: '1',
    standardName: '当前就读学校',
    standardNumber: 'BIDQ000000001',
    path: '/指标标准/DMP_admin-个人工作区/...',
    associationRelation:'无',
    associationDescription: '无',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
]
/**关联关系 表格6 数据*/
export const relatedRelationshipsData6 = [
  {
    businessId: '1',
    dataSource: '🌐mysql_test',
    directory: '无',
    database:'moe_data',
    dataTable:'graduates_info_bak',
    field:'is_full_time',
    associationDescription: '无',
    associationTime: '2024-01-01 10:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '2',
    dataSource: '🌐mysql_test',
    directory: '无',
    database:'moe_data',
    dataTable:'graduates_info',
    field:'is_full_time',
    associationDescription: '无',
    associationTime: '2024-01-02 11:00:00',
    operatorUser: 'DMP_admin',
  },
  {
    businessId: '3',
    dataSource: '🔍mysql_test',
    directory: '无',
    database:'moe_data',
    dataTable:'graduates_info',
    field:'is_full_time',
    associationDescription: '无',
    associationTime: '2024-01-03 12:00:00',
    operatorUser: 'DMP_admin',
  },
]

/**关联关系 关联质量 数据*/
export const relatedQualityData = [
  {
    parameter: 'value_a',
    templateType: '数值类',
    templateDescription: '数值类:大于n',
    value:'0',
  },
]
/**关联关系-质量模版-树 数据*/
export const qualityTreeData: any[] = [
  {
    "businessId": 100,
    "QualityName": "质量模版",
    "anotherName": "质量模版",
    "parentId": 0,
    "location": "/质量模版",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 101,
    "QualityName": "CEA_POC_模版",
    "anotherName": "CEA_POC_模版",
    "parentId": 100,
    "ancestors": "0,100",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 102,
    "QualityName": "数据中台工作区01",
    "anotherName": "数据中台工作区01",
    "parentId": 100,
    "ancestors": "0,100",
    "location": "/质量模版/数据中台工作区01",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 201,
    "QualityName": "值域检查(倍数)",
    "anotherName": "值域检查(倍数)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/质量模版/数据中台工作区01/值域检查(倍数)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 202,
    "QualityName": "值域检查(数值大于零)",
    "anotherName": "值域检查(数值大于零)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/质量模版/数据中台工作区01/值域检查(数值大于零)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 204,
    "QualityName": "准取检查-数值大于等于n",
    "anotherName": "准取检查-数值大于等于n",
    "parentId": 101,
    "ancestors": "0,100,101",
    "location": "/质量模版/CEA_POC_模版/准取检查-数值大于等于n",
    "icon": "ant-design:partition-outlined",
  }
];
/**关联关系-文档-树 数据*/
export const documentTreeData: any[] = [
  {
    "businessId": 100,
    "documentName": "文档模版",
    "anotherName": "文档模版",
    "parentId": 0,
    "location": "/文档模版",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 101,
    "documentName": "CEA_POC_模版",
    "anotherName": "CEA_POC_模版",
    "parentId": 100,
    "ancestors": "0,100",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 102,
    "documentName": "数据中台工作区01",
    "anotherName": "数据中台工作区01",
    "parentId": 100,
    "ancestors": "0,100",
    "location": "/文档模版/数据中台工作区01",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 201,
    "documentName": "值域检查(倍数)",
    "anotherName": "值域检查(倍数)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(倍数)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 202,
    "documentName": "值域检查(数值大于零)",
    "anotherName": "值域检查(数值大于零)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(数值大于零)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 204,
    "documentName": "准取检查-数值大于等于n",
    "anotherName": "准取检查-数值大于等于n",
    "parentId": 101,
    "ancestors": "0,100,101",
    "location": "/文档模版/CEA_POC_模版/准取检查-数值大于等于n",
    "icon": "ant-design:partition-outlined",
  }
];
/**关联关系-元数据-树 数据*/
export const meteDataTreeData: any[] = [
  {
    delFlag: '0',
    flag: '1',
    businessId: 100,
    workSpaceName: '数据库对象资源',
    parentId: 0,
    ancestors: '0',
    orderNum: 0,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 101,
    workSpaceName: 'admin-个人工作区',
    parentId: 100,
    ancestors: '0,100',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 102,
    workSpaceName: '共享工作区',
    parentId: 100,
    ancestors: '0,100',
    orderNum: 2,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '0',
    businessId: 103,
    workSpaceName: '高级工作区',
    parentId: 100,
    ancestors: '0,100',
    orderNum: 2,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 201,
    workSpaceName: 'mysql',
    parentId: 101,
    ancestors: '0,100,101',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 301,
    workSpaceName: 'gxx',
    parentId: 201,
    ancestors: '0,100,101,201',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 401,
    workSpaceName: 'batch3_prc',
    parentId: 301,
    ancestors: '0,100,101,201,301',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 202,
    workSpaceName: 'oracle',
    parentId: 102,
    ancestors: '0,100,102',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 203,
    workSpaceName: 'localhost',
    parentId: 103,
    ancestors: '0,100,103',
    orderNum: 1,
    children: [],
    selectType: null,
    createTime: '2024-10-24 10:04:04',
    createBy: 'admin',
  },
]
/**关联关系-指标标准-树 数据*/
export const indicatorTreeData: any[] = [
  {
    "businessId": 100,
    "indicatorStandardsName": "指标标准",
    "anotherName": "指标标准",
    "parentId": 0,
    "location": "/指标标准",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 101,
    "indicatorStandardsName": "CEA_POC_模版",
    "anotherName": "CEA_POC_模版",
    "parentId": 100,
    "ancestors": "0,100",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 102,
    "indicatorStandardsName": "数据中台工作区01",
    "anotherName": "数据中台工作区01",
    "parentId": 100,
    "ancestors": "0,100",
    "location": "/文档模版/数据中台工作区01",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 201,
    "indicatorStandardsName": "值域检查(倍数)",
    "anotherName": "值域检查(倍数)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(倍数)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 202,
    "indicatorStandardsName": "值域检查(数值大于零)",
    "anotherName": "值域检查(数值大于零)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(数值大于零)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 204,
    "indicatorStandardsName": "准取检查-数值大于等于n",
    "anotherName": "准取检查-数值大于等于n",
    "parentId": 101,
    "ancestors": "0,100,101",
    "location": "/文档模版/CEA_POC_模版/准取检查-数值大于等于n",
    "icon": "ant-design:partition-outlined",
  }
];
/**关联关系-公共代码-树 数据*/
export const publicCodeTreeData: any[] = [
  {
    "businessId": 100,
    "publicCodeName": "公共代码",
    "anotherName": "公共代码",
    "parentId": 0,
    "location": "/公共代码",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 101,
    "publicCodeName": "CEA_POC_模版",
    "anotherName": "CEA_POC_模版",
    "parentId": 100,
    "ancestors": "0,100",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 102,
    "publicCodeName": "数据中台工作区01",
    "anotherName": "数据中台工作区01",
    "parentId": 100,
    "ancestors": "0,100",
    "location": "/文档模版/数据中台工作区01",
    "icon": "ant-design:folder-open-outlined",
  },
  {
    "businessId": 201,
    "publicCodeName": "值域检查(倍数)",
    "anotherName": "值域检查(倍数)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(倍数)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 202,
    "publicCodeName": "值域检查(数值大于零)",
    "anotherName": "值域检查(数值大于零)",
    "parentId": 102,
    "ancestors": "0,100,102",
    "location": "/文档模版/数据中台工作区01/值域检查(数值大于零)",
    "icon": "ant-design:partition-outlined",
  },
  {
    "businessId": 204,
    "publicCodeName": "准取检查-数值大于等于n",
    "anotherName": "准取检查-数值大于等于n",
    "parentId": 101,
    "ancestors": "0,100,101",
    "location": "/文档模版/CEA_POC_模版/准取检查-数值大于等于n",
    "icon": "ant-design:partition-outlined",
  }
];
/**关联关系-智能推荐元数据 数据*/
export const recommendedMetadataData = [
  {
    businessId:'1',
    fieldName: 'current_school',
    fieldComment: '数值类',
    fieldType: 'string',
    recommendationLevel:'100%',
    mappingDescription:''
  },
  {
     businessId:'2',
    fieldName: 'current_school',
    fieldComment: '数值类',
    fieldType: 'string',
    recommendationLevel:'98%',
    mappingDescription:''
  },
  {
    businessId:'3',
    fieldName: 'current_school',
    fieldComment: '数值类',
    fieldType: 'string',
    recommendationLevel:'99%',
    mappingDescription:''
  },
  {
    businessId:'4',
    fieldName: 'current_school',
    fieldComment: '数值类',
    fieldType: 'string',
    recommendationLevel:'100%',
    mappingDescription:''
  },
  {
    businessId:'5',
    fieldName: 'current_school',
    fieldComment: '数值类',
    fieldType: 'string',
    recommendationLevel:'95',
    mappingDescription:''
  },
]
